/// <reference types="react" />
import * as React from 'react';
import { ScrollableInternalEmitter } from './Scrollable.const';
import { SCROLLBAR_TYPE } from '../Scrollbar/Scrollbar';
import { TResizeDetectorProps } from '../ResizeDetector/ResizeDetector';
import { THorizontalScrollbarProps } from '../Scrollbar/HorizontalScrollbar';
import { TVerticalScrollbarProps } from '../Scrollbar/VerticalScrollbar';
import * as PropTypes from 'prop-types';
import { ObjectClean } from 'typelevel-ts';
import { PartialKeys } from '@devexperts/utils/lib/object/object';
export declare const SCROLLABLE: symbol;
export declare type TFullScrollableProps = {
    children: React.ReactNode;
    ResizeDetector: React.ComponentClass<TResizeDetectorProps>;
    HorizontalScrollbar: React.ComponentClass<THorizontalScrollbarProps>;
    VerticalScrollbar: React.ComponentClass<TVerticalScrollbarProps>;
    theme: {
        scrollable?: string;
        withHorizontalScrollbar?: string;
        withVerticalScrollbar?: string;
        scrollbar?: string;
        container: string;
        wrapper?: string;
        content?: string;
        resizeDetector?: string;
        horizontal_scrollbar__bar?: string;
        vertical_scrollbar__bar?: string;
    };
    onUpdate?: (withHorizantal: boolean, withVertical: boolean) => void;
    onScroll?: (scrollLeft: number, scrollTop: number) => void;
    scrollTop?: number;
    scrollLeft?: number;
};
export declare class RawScrollable extends React.Component<TFullScrollableProps> {
    static defaultProps: {
        ResizeDetector: React.ComponentClass<Pick<PartialKeys<{
            theme: {
                container?: string | undefined;
            };
            onResize: (element: Element) => any;
        }, "theme">, "theme" | "onResize">>;
        VerticalScrollbar: React.ComponentClass<Pick<PartialKeys<{
            container: HTMLDivElement;
            theme: {
                container?: string | undefined;
                containerIsVisible?: string | undefined;
                track?: string | undefined;
                bar?: string | undefined;
            };
        } & {
            scrollTop?: number | undefined;
        }, "theme">, "theme" | "container" | "scrollTop">>;
        HorizontalScrollbar: React.ComponentClass<Pick<PartialKeys<{
            container: HTMLDivElement;
            theme: {
                container?: string | undefined;
                containerIsVisible?: string | undefined;
                track?: string | undefined;
                bar?: string | undefined;
            };
        } & {
            scrollLeft?: number | undefined;
        }, "theme">, "theme" | "container" | "scrollLeft">>;
    };
    static childContextTypes: {
        [x: string]: PropTypes.Validator<any>;
        size: PropTypes.Requireable<any>;
    };
    _withHorizontalScrollbar: boolean;
    _withVerticalScrollbar: boolean;
    _container: HTMLDivElement | null;
    _scrollable: HTMLDivElement | null;
    _emitter: ScrollableInternalEmitter;
    _horizontalScrollbar: HTMLDivElement | null;
    _verticalScrollbar: HTMLDivElement | null;
    state: {
        container: undefined;
        scrollable: undefined;
    };
    getChildContext(): {
        [x: string]: ScrollableInternalEmitter | {
            width: number;
            height: number;
        };
        size: {
            width: number;
            height: number;
        };
    };
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentWillMount(): void;
    onScroll: (event: React.MouseEvent<HTMLDivElement>) => void;
    onScrollbarUpdate: (type: SCROLLBAR_TYPE, isVisible: boolean) => void;
    render(): JSX.Element;
    onResize: () => void;
}
export declare type TScrollableProps = ObjectClean<PartialKeys<TFullScrollableProps, 'theme' | 'ResizeDetector' | 'VerticalScrollbar' | 'HorizontalScrollbar'>>;
export declare const Scrollable: React.ComponentClass<TScrollableProps>;
