'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.shouldComponentUpdate = shouldComponentUpdate;
exports.PURE = PURE;

var _object = require('@devexperts/utils/lib/object/object');

/**
 * Pure render checker
 * @param {object} props
 * @param {object} state
 * @param {object} newProps
 * @param {object} newState
 * @returns {boolean}
 */
function shouldComponentUpdate(props, state, newProps, newState) {
    return !(0, _object.shallowEqual)(props, newProps) || !(0, _object.shallowEqual)(state, newState);
}
/**
 * Pure render recorator
 */
function PURE(target) {
    //noinspection JSUnresolvedVariable
    var oldShouldComponentUpdate = target.prototype.shouldComponentUpdate;
    /**
     * @param {*} newProps
     * @param {*} newState
     * @returns {boolean}
     */
    target.prototype.shouldComponentUpdate = function (newProps, newState) {
        //check original shoulComponentUpdate
        var shouldUpdateByOriginal = !oldShouldComponentUpdate || oldShouldComponentUpdate.call(this, newProps, newState);
        //check props.theme which can be set by react-css-themr
        var shouldCheckTheme = !!newProps['theme'];
        //check shallow equality
        //will be set further basing on shouldCheckCss
        var shouldUpdateByEquality = void 0;
        if (shouldCheckTheme) {
            //now we need to remove theme object from original props to avoid checking by shouldComponentUpdate
            var thisPropsCopy = Object.assign({}, this.props);
            var newPropsCopy = Object.assign({}, newProps);
            delete thisPropsCopy['theme'];
            delete newPropsCopy['theme'];
            //check
            shouldUpdateByEquality =
            //either props has changed (ignoring css)
            shouldComponentUpdate(thisPropsCopy, this.state, newPropsCopy, newState) ||
            //or theme has changed
            !(0, _object.deepEqual)(this.props.theme, newProps['theme']);
        } else {
            //we don't need to do anything with the props so just call shouldComponentUpdate
            shouldUpdateByEquality = shouldComponentUpdate(this.props, this.state, newProps, newState);
        }
        return shouldUpdateByOriginal && shouldUpdateByEquality;
    };
    return target;
}